import plotly.graph_objects as go

from polisher import cleaner
from polisher.configs import GREY


def test_remove_grids():
    """Should set show grid to false for y and x axis"""
    fig = go.Figure()
    cleaned_fig = cleaner.remove_grids(figure=fig)
    assert not cleaned_fig.layout.xaxis.showgrid
    assert not cleaned_fig.layout.yaxis.showgrid


def test_remove_background():
    """Should set paper bg color and plot bg color to rgba(0,0,0,0)"""
    fig = go.Figure()
    cleaned_fig = cleaner.remove_background(figure=fig)
    assert cleaned_fig.layout.plot_bgcolor == 'rgba(0,0,0,0)'


def test_send_to_background():
    """Should set everything grey"""
    fig = go.Figure(go.Bar(x=[1, 2, 3], y=[1, 2, 3]))
    cleaned_fig = cleaner.send_to_background(figure=fig)

    assert cleaned_fig.layout.title.font.color == GREY
    assert cleaned_fig.layout.xaxis.color == GREY
    assert cleaned_fig.layout.yaxis.color == GREY
    assert cleaned_fig.data[0]['marker']['color'] == GREY


def test_send_to_background_keep_trace_colors():
    """Should set everything grey"""
    fig = go.Figure(go.Bar(x=[1, 2, 3], y=[1, 2, 3]))
    cleaned_fig = cleaner.send_to_background(figure=fig, keep_trace_colors=True)

    assert cleaned_fig.layout.title.font.color == GREY
    assert cleaned_fig.layout.xaxis.color == GREY
    assert cleaned_fig.layout.yaxis.color == GREY
    assert cleaned_fig.data[0]['marker']['color'] != GREY



from plotly.graph_objects import Figure

from polisher.configs import GREY


def remove_grids(
    figure: Figure,
    keep_y_axis_grid: bool = False,
    keep_x_axis_grid: bool = False
) -> Figure:
    """
    Removes grids from layout. Grids are not necessary most of the time; it
    is good practice to only use them when necessary.
    :param figure: The figure to remove the grids.
    :param keep_y_axis_grid: To keep y axis grid lines or not.
    :param keep_x_axis_grid: To keep x axis grid lines or not.
    """
    return figure.update_layout(
        xaxis_showgrid=keep_x_axis_grid, yaxis_showgrid=keep_y_axis_grid
    )


def remove_background(
    figure: Figure, color: str = 'rgba(0,0,0,0)'
) -> Figure:
    """
    Removes background from layout by setting them to white.
    :param figure: The figure to remove the background.
    :param color: The rgba color
    """
    return figure.update_layout({
        'plot_bgcolor': color
    })


def send_to_background(
    figure: Figure, color: str = GREY, keep_trace_colors: bool = False
) -> Figure:
    """
    De-prioritize graphic importance by neutralizing the color of everything.
    Setting it to grey, will allow us later to only add color to what really
    matters in the plot.

    What will be set to grey? The axis titles, the trace colors, the title, and
    the xaxis and yaxis labels.

    :param figure: The figure to set everything to grey
    :param color: The color to set the everything to.
    :param keep_trace_colors: If true, function will skip setting trace colors.
    """
    figure.update_layout({'title_font_color': color})
    figure.update_xaxes({
        'title_font_color': color,
        'color': color,
    })
    figure.update_yaxes({
        'title_font_color': color,
        'color': color,
    })
    figure.update_annotations({
        'font_color': color,
    })
    # can be multiple colors for the whole series.
    if not keep_trace_colors:
        figure.update_traces({'marker_color': color})
    return figure



import pathlib
import setuptools

HERE = pathlib.Path(__file__).parent

README = (HERE / 'README.md').read_text()

setuptools.setup(
    name="polisher",
    version="2.0.0",
    author="Rodrigo da Silva",
    author_email="dasil021@umn.edu",
    description=(
        "polisher is a library that helps you clean your plotly figures.. "
        "This library is inspired by the book Storytelling with Data by Cole "
        "Nussbaumer Knaflic (https://www.kobo.com/us/en/ebook/storytelling-"
        "with-data)."
    ),
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://gitlab.com/rigogsilva/polisher",
    license='MIT',
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
